streamViewType property
The type of data from the modified DynamoDB item that was captured in this stream record:
-
KEYS_ONLY- only the key attributes of the modified item. -
NEW_IMAGE- the entire item, as it appeared after it was modified. -
OLD_IMAGE- the entire item, as it appeared before it was modified. -
NEW_AND_OLD_IMAGES- both the new and the old item images of the item.
Implementation
final StreamViewType? streamViewType;